summaryrefslogtreecommitdiff
path: root/Tools/gtk/patches/gst-plugins-base-rtp-rtcpbuffer-fix-typo-in-enum.patch
blob: e3ddb72381b36f4cdce87df48028d7aa3fefaf22 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
From dfc34c58411f50b37b2e1300560ae8a0b6a9a7d4 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Tim-Philipp=20M=C3=BCller?= <tim@centricular.com>
Date: Tue, 7 Apr 2015 16:43:59 +0100
Subject: [PATCH] rtp: rtcpbuffer: fix typo in enum

and in docs. Spotted by Rob Swain.
---
 gst-libs/gst/rtp/gstrtcpbuffer.h | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/gst-libs/gst/rtp/gstrtcpbuffer.h b/gst-libs/gst/rtp/gstrtcpbuffer.h
index b5ff4a1..47378cf 100644
--- a/gst-libs/gst/rtp/gstrtcpbuffer.h
+++ b/gst-libs/gst/rtp/gstrtcpbuffer.h
@@ -59,6 +59,9 @@ typedef enum
   GST_RTCP_TYPE_PSFB    = 206
 } GstRTCPType;
 
+/* FIXME 2.0: backwards compatibility define for enum typo */
+#define GST_RTCP_RTPFB_TYPE_RCTP_SR_REQ GST_RTCP_RTPFB_TYPE_RTCP_SR_REQ
+
 /**
  * GstRTCPFBType:
  * @GST_RTCP_FB_TYPE_INVALID: Invalid type
@@ -66,7 +69,7 @@ typedef enum
  * @GST_RTCP_RTPFB_TYPE_TMMBR: Temporary Maximum Media Stream Bit Rate Request
  * @GST_RTCP_RTPFB_TYPE_TMMBN: Temporary Maximum Media Stream Bit Rate
  *    Notification
  * @GST_RTCP_RTPFB_TYPE_RTCP_SR_SEQ: Request an SR packet for early
  *    synchronization
  * @GST_RTCP_PSFB_TYPE_PLI: Picture Loss Indication
  * @GST_RTCP_PSFB_TYPE_SLI: Slice Loss Indication
@@ -89,7 +92,7 @@ typedef enum
   GST_RTCP_RTPFB_TYPE_TMMBR       = 3,
   GST_RTCP_RTPFB_TYPE_TMMBN       = 4,
   /* RTPFB types assigned in RFC 6051 */
-  GST_RTCP_RTPFB_TYPE_RCTP_SR_REQ = 5,
+  GST_RTCP_RTPFB_TYPE_RTCP_SR_REQ = 5,
   /* PSFB types */
   GST_RTCP_PSFB_TYPE_PLI          = 1,
   GST_RTCP_PSFB_TYPE_SLI          = 2,
@@ -66,7 +69,7 @@ typedef enum
  * @GST_RTCP_RTPFB_TYPE_TMMBN: Temporary Maximum Media Stream Bit Rate
  *    Notification
- * @GST_RTCP_RTPFB_TYPE_RTCP_SR_SEQ: Request an SR packet for early
+ * @GST_RTCP_RTPFB_TYPE_RTCP_SR_REQ: Request an SR packet for early
  *    synchronization
  * @GST_RTCP_PSFB_TYPE_PLI: Picture Loss Indication
-- 
2.1.4